pub struct Metrics {
samples: Vec<Sample>,
}Fields
samples: Vec<Sample>Implementations
Sourceimpl Metrics
impl Metrics
Sourcepub fn from_context(context: &impl Metrics) -> Self
pub fn from_context(context: &impl Metrics) -> Self
Samples metrics from a Commonware runtime context.
pub fn value<T>(&self, metric_suffix: &str) -> Option<T>
pub fn values<'a, T>( &'a self, metric_suffix: &'a str, ) -> impl Iterator<Item = T> + 'a
Sourcepub fn for_scope(&self, scope: &impl MetricScope) -> Self
pub fn for_scope(&self, scope: &impl MetricScope) -> Self
Returns metrics for a metric-emitting runtime scope.
Sourcepub fn consensus_at_height(&self, target_height: u64) -> usize
pub fn consensus_at_height(&self, target_height: u64) -> usize
Counts consensus instances whose processed height is at least target_height.
Sourcepub fn consensus_at_epoch(&self, target_epoch: u64) -> usize
pub fn consensus_at_epoch(&self, target_epoch: u64) -> usize
Counts consensus instances whose latest epoch is at least target_epoch.
pub fn latest_consensus_epoch(&self) -> Option<u64>
pub fn latest_consensus_height(&self) -> Option<u64>
pub fn consensus_before_epoch(&self, upper_bound: u64) -> bool
pub fn has_consensus_participants(&self, target: u64) -> bool
Sourcepub fn assert_no_blocked_peers(&self)
pub fn assert_no_blocked_peers(&self)
Asserts that all peers_blocked metrics are zero.
Sourcepub fn assert_no_dkg_failures(&self)
pub fn assert_no_dkg_failures(&self)
Asserts that all DKG ceremony failure counters are zero.
Sourcepub fn assert_any_rounds_skipped(&self)
pub fn assert_any_rounds_skipped(&self)
Asserts that at least one consensus instance skipped rounds.